@@ -6,6 +6,22 @@ from ccpages.models import Page
 
 class ListenerTestCases(TestCase):
 
+    def test_content_rendered(self):
+        """When a page is saved the content is passed through
+        markdown and saved as content_rendered"""
+        page1 = Page()
+        page1.title = '1'
+        page1.slug = '1'
+        page1.content = '# Hello World'
+        page1.order = Decimal('1')
+        page1.password = 'ha'
+        page1.status = Page.VISIBLE
+        page1.save()
+        # we now have rendered content
+        self.assertHTMLEqual(
+                page1.content_rendered,
+                '<h1>Hello World</h1>')
+
     def test_hash_if_password(self):
         """A hash is generated on save if page has password"""
         page1 = Page()
